@@ -840,19 +840,18 @@ def AddInstanceFlexibilityPolicyArgs(
 
 def AddTargetSizePolicyModeFlag(parser):
   """Add target size policy mode to the parser."""
-  help_text = 'Specifies mode in which operations on size are processed.'
+  help_text = 'Specifies the mode in which the MIG creates VMs in the group.'
   choices = {
       'individual': (
-          'Default mode in which MIG creates and starts VMs individually'
-          ' without cross-dependency between VMs. This means that in case of'
-          ' something blocking part of VMs to be provisioned, the other part'
-          ' will be created.'
+          '(Default) MIG creates VMs individually. If the MIG cannot create any'
+          ' VM to meet the specified ``size``, then the MIG creates the VMs for'
+          ' which resources are available. The MIG then attempts to create the'
+          ' remaining VMs until the resources become available.'
       ),
       'bulk': (
-          'Mode in which MIG creates and starts VMs in all-or-nothing manner.'
-          ' If any VM from the request cannot be provisioned, the whole request'
-          ' waits for conditions that allow for provisioning whole capacity in'
-          ' bulk.'
+          'MIG creates VMs all at once. If the MIG cannot create any VM to meet'
+          ' the specified ``size``, then the MIG waits until the resources'
+          ' become available to create all VMs.'
       ),
   }
 
@@ -876,7 +875,6 @@ def AddWorkloadPolicyFlag(parser: parser_arguments.ArgumentInterceptor):
           'can be a full or partial URL to a resource policy containing '
           'the workload policy.'
       ),
-      hidden=True,
   )
 
 
@@ -888,13 +886,12 @@ def AddRemoveWorkloadPolicyFlag(parser: parser_arguments.ArgumentInterceptor):
       help=(
           'Detaches the workload policy from the managed instance group.'
       ),
-      hidden=True,
   )
 
 
 def AddWorkloadPolicyFlags(parser: parser_arguments.ArgumentInterceptor):
   """Add flags for managing workload policy."""
-  workload_policy_group = parser.add_group(mutex=True, hidden=True)
+  workload_policy_group = parser.add_group(mutex=True)
   AddWorkloadPolicyFlag(workload_policy_group)
   AddRemoveWorkloadPolicyFlag(workload_policy_group)
 
@@ -938,3 +935,18 @@ class ArgMultiValueDict:
       arg_dict.setdefault(key, []).append(value)
 
     return arg_dict
+
+
+def AddOnRepairFlags(parser: parser_arguments.ArgumentInterceptor):
+  """Add on repair flags to the parser."""
+  allow_changing_zone_choices = {
+      'no': "(Default) MIG cannot change a VM's zone during a repair.",
+      'yes': 'MIG can select a different zone for the VM during a repair.',
+  }
+  parser.add_argument(
+      '--on-repair-allow-changing-zone',
+      metavar='ON_REPAIR_ALLOW_CHANGING_ZONE',
+      type=arg_utils.EnumNameToChoice,
+      choices=allow_changing_zone_choices,
+      help="Specifies whether the MIG can change a VM's zone during a repair.",
+  )
