@@ -117,6 +117,8 @@ for examples.
   parser.display_info.AddFormat(util.NODEPOOLS_FORMAT)
   flags.AddNodeVersionFlag(parser)
   flags.AddDiskTypeFlag(parser)
+  flags.AddBootDiskProvisionedThroughputFlag(parser)
+  flags.AddBootDiskProvisionedIopsFlag(parser)
   flags.AddMetadataFlags(parser)
   flags.AddShieldedInstanceFlags(parser)
   flags.AddNetworkConfigFlags(parser)
@@ -126,8 +128,13 @@ for examples.
   flags.AddAdditionalPodNetworkFlag(parser)
   flags.AddAsyncFlag(parser)
   flags.AddSoleTenantNodeAffinityFileFlag(parser)
+  flags.AddSoleTenantMinNodeCpusFlag(parser)
   flags.AddContainerdConfigFlag(parser)
   flags.AddEnableKubeletReadonlyPortFlag(parser)
+  flags.AddGpuDirectStrategyFlag(parser)
+  flags.AddEnableKernelModuleSignatureEnforcementFlag(
+      parser, for_node_pool=True, hidden=True
+  )
 
 
 def ParseCreateNodePoolOptionsBase(args):
@@ -194,6 +201,7 @@ def ParseCreateNodePoolOptionsBase(args):
       reservation_affinity=args.reservation_affinity,
       reservation=args.reservation,
       sandbox=args.sandbox,
+      gpudirect_strategy=args.gpudirect_strategy,
       max_surge_upgrade=args.max_surge_upgrade,
       max_unavailable_upgrade=args.max_unavailable_upgrade,
       node_group=args.node_group,
@@ -211,6 +219,7 @@ def ParseCreateNodePoolOptionsBase(args):
       enable_surge_upgrade=args.enable_surge_upgrade,
       node_pool_soak_duration=args.node_pool_soak_duration,
       standard_rollout_policy=args.standard_rollout_policy,
+      autoscaled_rollout_policy=args.autoscaled_rollout_policy,
       enable_private_nodes=args.enable_private_nodes,
       enable_fast_socket=args.enable_fast_socket,
       logging_variant=args.logging_variant,
@@ -218,10 +227,15 @@ def ParseCreateNodePoolOptionsBase(args):
       additional_node_network=args.additional_node_network,
       additional_pod_network=args.additional_pod_network,
       sole_tenant_node_affinity_file=args.sole_tenant_node_affinity_file,
+      sole_tenant_min_node_cpus=args.sole_tenant_min_node_cpus,
       containerd_config_from_file=args.containerd_config_from_file,
       resource_manager_tags=args.resource_manager_tags,
       enable_insecure_kubelet_readonly_port=args.enable_insecure_kubelet_readonly_port,
       enable_nested_virtualization=args.enable_nested_virtualization,
+      boot_disk_provisioned_iops=args.boot_disk_provisioned_iops,
+      boot_disk_provisioned_throughput=args.boot_disk_provisioned_throughput,
+      accelerator_network_profile=args.accelerator_network_profile,
+      enable_kernel_module_signature_enforcement=args.enable_kernel_module_signature_enforcement,
   )
 
 
@@ -270,6 +284,7 @@ class Create(base.CreateCommand):
     flags.AddEnableSurgeUpgradeFlag(parser)
     flags.AddEnableBlueGreenUpgradeFlag(parser)
     flags.AddStandardRolloutPolicyFlag(parser)
+    flags.AddAutoscaledRolloutPolicyFlag(parser)
     flags.AddStoragePoolsFlag(
         parser, for_node_pool=True, for_create=True)
     flags.AddNodePoolSoakDurationFlag(parser)
@@ -279,6 +294,7 @@ class Create(base.CreateCommand):
     flags.AddWindowsOsVersionFlag(parser)
     flags.AddPlacementTypeFlag(parser, for_node_pool=True, hidden=False)
     flags.AddQueuedProvisioningFlag(parser)
+    flags.AddConsolidationDelayFlag(parser, hidden=True)
     flags.AddMaxRunDurationFlag(parser)
     flags.AddFlexStartFlag(parser)
     flags.AddBestEffortProvisionFlags(parser)
@@ -290,6 +306,7 @@ class Create(base.CreateCommand):
     flags.AddSecondaryBootDisksArgs(parser)
     flags.AddEnableConfidentialStorageFlag(parser, for_node_pool=True)
     flags.AddDataCacheCountFlag(parser, for_node_pool=True)
+    flags.AddAcceleratorNetworkProfileFlag(parser)
 
   def ParseCreateNodePoolOptions(self, args):
     ops = ParseCreateNodePoolOptionsBase(args)
@@ -303,10 +320,12 @@ class Create(base.CreateCommand):
     ops.placement_policy = args.placement_policy
     ops.enable_queued_provisioning = args.enable_queued_provisioning
     ops.max_run_duration = args.max_run_duration
+    ops.consolidation_delay = args.consolidation_delay
     ops.flex_start = args.flex_start
     ops.tpu_topology = args.tpu_topology
     ops.secondary_boot_disks = args.secondary_boot_disk
     ops.storage_pools = args.storage_pools
+
     return ops
 
   def Run(self, args):
@@ -416,7 +435,7 @@ class CreateBeta(Create):
     flags.AddEnableSurgeUpgradeFlag(parser)
     flags.AddEnableBlueGreenUpgradeFlag(parser)
     flags.AddStandardRolloutPolicyFlag(parser)
-    flags.AddAutoscaleRolloutPolicyFlag(parser)
+    flags.AddAutoscaledRolloutPolicyFlag(parser)
     flags.AddNodePoolSoakDurationFlag(parser)
     flags.AddMaintenanceIntervalFlag(parser, for_node_pool=True, hidden=True)
     flags.AddNetworkPerformanceConfigFlags(parser, hidden=False)
@@ -434,6 +453,7 @@ class CreateBeta(Create):
     flags.AddWindowsOsVersionFlag(parser)
     flags.AddBestEffortProvisionFlags(parser, hidden=False)
     flags.AddQueuedProvisioningFlag(parser)
+    flags.AddConsolidationDelayFlag(parser, hidden=True)
     flags.AddMaxRunDurationFlag(parser)
     flags.AddFlexStartFlag(parser)
     flags.AddTPUTopologyFlag(parser)
@@ -444,6 +464,7 @@ class CreateBeta(Create):
     flags.AddOpportunisticMaintenanceFlag(parser)
     flags.AddResourceManagerTagsCreate(parser, for_node_pool=True)
     flags.AddSecondaryBootDisksArgs(parser)
+    flags.AddAcceleratorNetworkProfileFlag(parser, hidden=False)
 
   def ParseCreateNodePoolOptions(self, args):
     ops = ParseCreateNodePoolOptionsBase(args)
@@ -480,6 +501,7 @@ class CreateBeta(Create):
     ops.enable_fast_socket = args.enable_fast_socket
     ops.enable_queued_provisioning = args.enable_queued_provisioning
     ops.max_run_duration = args.max_run_duration
+    ops.consolidation_delay = args.consolidation_delay
     ops.flex_start = args.flex_start
     ops.tpu_topology = args.tpu_topology
     ops.enable_nested_virtualization = args.enable_nested_virtualization
@@ -526,6 +548,7 @@ class CreateAlpha(Create):
     ops.enable_surge_upgrade = args.enable_surge_upgrade
     ops.node_pool_soak_duration = args.node_pool_soak_duration
     ops.standard_rollout_policy = args.standard_rollout_policy
+    ops.autoscaled_rollout_policy = args.autoscaled_rollout_policy
     ops.maintenance_interval = args.maintenance_interval
     ops.network_performance_config = args.network_performance_configs
     ops.enable_confidential_nodes = args.enable_confidential_nodes
@@ -534,6 +557,7 @@ class CreateAlpha(Create):
     ops.enable_fast_socket = args.enable_fast_socket
     ops.enable_queued_provisioning = args.enable_queued_provisioning
     ops.max_run_duration = args.max_run_duration
+    ops.consolidation_delay = args.consolidation_delay
     ops.flex_start = args.flex_start
     ops.tpu_topology = args.tpu_topology
     ops.enable_nested_virtualization = args.enable_nested_virtualization
@@ -542,12 +566,28 @@ class CreateAlpha(Create):
     ops.host_maintenance_interval = args.host_maintenance_interval
     ops.opportunistic_maintenance = args.opportunistic_maintenance
     ops.performance_monitoring_unit = args.performance_monitoring_unit
-    ops.autoscaled_rollout_policy = args.autoscaled_rollout_policy
     ops.ephemeral_storage = ephemeral_storage
     ops.secondary_boot_disks = args.secondary_boot_disk
     ops.storage_pools = args.storage_pools
     ops.local_ssd_encryption_mode = args.local_ssd_encryption_mode
     ops.data_cache_count = args.data_cache_count
+
+    if args.enable_attestation and not args.tee_policy:
+      raise exceptions.InvalidArgumentException(
+          '--enable-attestation',
+          'The --tee-policy flag must be provided when --enable-attestation is'
+          ' specified.',
+      )
+    if args.tee_policy and not args.enable_attestation:
+      raise exceptions.InvalidArgumentException(
+          '--tee-policy',
+          'The --enable-attestation flag must be provided when --tee-policy is'
+          ' specified.',
+      )
+    ops.runner_pool_control_mode = args.runner_pool_control_mode
+    ops.control_node_pool = args.control_node_pool
+    ops.enable_attestation = args.enable_attestation
+    ops.tee_policy = args.tee_policy
     return ops
 
   @staticmethod
@@ -590,6 +630,7 @@ class CreateAlpha(Create):
     flags.AddEnableSurgeUpgradeFlag(parser)
     flags.AddEnableBlueGreenUpgradeFlag(parser)
     flags.AddStandardRolloutPolicyFlag(parser, for_node_pool=True)
+    flags.AddAutoscaledRolloutPolicyFlag(parser)
     flags.AddNodePoolSoakDurationFlag(parser, for_node_pool=True)
     flags.AddMaintenanceIntervalFlag(parser, for_node_pool=True, hidden=True)
     flags.AddNetworkPerformanceConfigFlags(parser, hidden=False)
@@ -607,6 +648,7 @@ class CreateAlpha(Create):
     flags.AddWindowsOsVersionFlag(parser)
     flags.AddBestEffortProvisionFlags(parser, hidden=False)
     flags.AddQueuedProvisioningFlag(parser)
+    flags.AddConsolidationDelayFlag(parser, hidden=True)
     flags.AddMaxRunDurationFlag(parser)
     flags.AddFlexStartFlag(parser)
     flags.AddTPUTopologyFlag(parser)
@@ -615,8 +657,16 @@ class CreateAlpha(Create):
     flags.AddHostMaintenanceIntervalFlag(
         parser, for_node_pool=True, hidden=True)
     flags.AddOpportunisticMaintenanceFlag(parser)
-    flags.AddAutoscaleRolloutPolicyFlag(parser)
     flags.AddResourceManagerTagsCreate(parser, for_node_pool=True)
     flags.AddSecondaryBootDisksArgs(parser)
+    flags.AddAcceleratorNetworkProfileFlag(parser, hidden=False)
+    linked_runner_group = parser.add_group(mutex=True, hidden=True)
+    flags.AddRunnerPoolControlModeFlag(linked_runner_group, hidden=True)
+    runner_pool_group = linked_runner_group.add_group()
+    flags.AddControlNodePoolFlag(runner_pool_group, hidden=True)
+    attestation_group = runner_pool_group.add_group(
+        help='Settings for attestation.')
+    flags.AddEnableAttestationFlag(attestation_group, hidden=True)
+    flags.AddTeePolicyFlag(attestation_group, hidden=True)
 
 Create.detailed_help = DETAILED_HELP
